@@ -14,10 +14,10 @@ class RundeckJobs(object):
     @logger.catch
     def search_uptimerobot(
             self,
-            deployment_action=os.environ.get('RD_OPTION_DEPLOYMENT_ACTION'),
-            uptimerobot_api_key=os.environ.get("RD_OPTION_UPTIMEROBOT_API_KEY"),
-            fqdn=os.environ.get("RD_OPTION_FQDN"),
-            force_apply=os.environ.get('RD_OPTION_FORCE_APPLY')):
+            deployment_action: str = os.environ.get('RD_OPTION_DEPLOYMENT_ACTION'),
+            uptimerobot_api_key: str = os.environ.get("RD_OPTION_UPTIMEROBOT_API_KEY"),
+            fqdn: str = os.environ.get("RD_OPTION_FQDN"),
+            force_apply: bool = os.environ.get('RD_OPTION_FORCE_APPLY')):
         if deployment_action != 'apply':
             print("Skipping website hosting check as deployment action is not apply")
             exit(0)
